==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/PullRequestTemplateOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for `PullRequestTemplate`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.770Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.PullRequestTemplateOptions")
@software.amazon.jsii.Jsii.Proxy(PullRequestTemplateOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface PullRequestTemplateOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The contents of the template.
     * <p>
     * You can use <code>addLine()</code> to add additional lines.
     * <p>
     * Default: - a standard default template will be created.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getLines() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link PullRequestTemplateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PullRequestTemplateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<PullRequestTemplateOptions> {
        java.util.List<java.lang.String> lines;

        /**
         * Sets the value of {@link PullRequestTemplateOptions#getLines}
         * @param lines The contents of the template.
         *              You can use <code>addLine()</code> to add additional lines.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lines(java.util.List<java.lang.String> lines) {
            this.lines = lines;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PullRequestTemplateOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public PullRequestTemplateOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link PullRequestTemplateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PullRequestTemplateOptions {
        private final java.util.List<java.lang.String> lines;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.lines = software.amazon.jsii.Kernel.get(this, "lines", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.lines = builder.lines;
        }

        @Override
        public final java.util.List<java.lang.String> getLines() {
            return this.lines;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getLines() != null) {
                data.set("lines", om.valueToTree(this.getLines()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.PullRequestTemplateOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PullRequestTemplateOptions.Jsii$Proxy that = (PullRequestTemplateOptions.Jsii$Proxy) o;

            return this.lines != null ? this.lines.equals(that.lines) : that.lines == null;
        }

        @Override
        public final int hashCode() {
            int result = this.lines != null ? this.lines.hashCode() : 0;
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/PullRequestTemplateOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for <code>PullRequestTemplate</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.436Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.PullRequestTemplateOptions")
@software.amazon.jsii.Jsii.Proxy(PullRequestTemplateOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface PullRequestTemplateOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The contents of the template.
     * <p>
     * You can use <code>addLine()</code> to add additional lines.
     * <p>
     * Default: - a standard default template will be created.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getLines() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link PullRequestTemplateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PullRequestTemplateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<PullRequestTemplateOptions> {
        java.util.List<java.lang.String> lines;

        /**
         * Sets the value of {@link PullRequestTemplateOptions#getLines}
         * @param lines The contents of the template.
         *              You can use <code>addLine()</code> to add additional lines.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lines(java.util.List<java.lang.String> lines) {
            this.lines = lines;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PullRequestTemplateOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public PullRequestTemplateOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link PullRequestTemplateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PullRequestTemplateOptions {
        private final java.util.List<java.lang.String> lines;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.lines = software.amazon.jsii.Kernel.get(this, "lines", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.lines = builder.lines;
        }

        @Override
        public final java.util.List<java.lang.String> getLines() {
            return this.lines;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getLines() != null) {
                data.set("lines", om.valueToTree(this.getLines()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.PullRequestTemplateOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PullRequestTemplateOptions.Jsii$Proxy that = (PullRequestTemplateOptions.Jsii$Proxy) o;

            return this.lines != null ? this.lines.equals(that.lines) : that.lines == null;
        }

        @Override
        public final int hashCode() {
            int result = this.lines != null ? this.lines.hashCode() : 0;
            return result;
        }
    }
}
